
#ifndef _C14_ds681_
#define _C14_ds681_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F920_6170(EIF_REFERENCE);
extern void EIF_Minit681(void);
extern char *(*R4601[])();

#ifdef __cplusplus
}
#endif

#endif
